==> libstpk-0.9.10.0.tar.gz: libstpk-0.9.10.0/demo/SEQ/sound_make.f90 <==
program sound_make
!  ǤΥǥ󥰥եץ.
!  ɬפ˱Ŭ񤭴.
!  ñ̤Ϥ٤ MKS ñ.
  use Thermo_Function
  use Algebra
  use Phys_Const
  use Thermo_Const
  use Thermo_Function

  implicit none

!-- namelist valiables
  integer :: nr, nz  ! ʿľʻ
  integer :: mom_flag
  real :: coril
  real :: dr, dz     ! ʿľʻҴֳ [m]
  character(4) :: bc  ! not use
  character(80) :: fname  ! not use
  character(80) :: sound_name  ! ǥ󥰥ե̾

  real, parameter :: t_s=300.0  ! ɽ̲
  real, parameter :: t_trop=200.0  ! ή̤Ǥβ
  real, parameter :: z_trop=15.0e3  ! ή̹
  real, allocatable :: z(:)  ! 
  real, allocatable :: temp(:)  ! 
  real, allocatable :: theta(:)  ! 
  real, allocatable :: pres(:)  ! 
  real, allocatable :: temp_inv(:)  ! 
  real :: gamma_dd  ! ٸΨ
  real :: p_s  ! ɽ̵,  3 ܻ.

  integer :: i

!-- namelist Υѥ᡼
  namelist /input /nr, nz, dr, dz, bc, fname, sound_name, coril, mom_flag
  read(5,nml=input)

!-- allocate
  allocate(z(nz))
  allocate(temp(nz))
  allocate(theta(nz))
  allocate(pres(nz))
  allocate(temp_inv(nz))

!-- ɽ̵η׻
  p_s=1000.0e2


  z=(/(dz*real(i-1),i=1,nz)/)

  gamma_dd=(t_trop-t_s)/z_trop  ! ̤ޤǤβٸΨ (constant)

  do i=1,nz
     if(z(i)<=z_trop)then
        temp(i)=t_s+gamma_dd*z(i)
     else
        temp(i)=t_trop
     end if
     temp_inv(i)=1.0/temp(i)
  end do

  pres(1)=p_s

  do i=2,nz
     pres(i)=p_s/((gamma_dd*z(i)/t_s+1.0)**(g/(Rd*gamma_dd)))  ! Ψ絤ˤϳشط뼰ѤƷ׻.
  end do

  do i=1,nz
     theta(i)=theta_dry( temp(i), pres(i) )
  end do

!-- ǥ󥰥եؤν񤭽Ф.
  open(unit=10,file=trim(sound_name),status='unknown')
  write(*,*) "output the sounding file."
  write(10,*) "'height',  'temperature',  'pressure',  'potential temperature'"
  write(10,*) "'m',  'K',  'Pa',  'K'"
  do i=1,nz
     write(10,'(100f)') z(i), temp(i), pres(i), theta(i)
  end do
  close(unit=10,status='keep')

end program

==> libstpk-0.9.17.0.tar.gz: libstpk-0.9.17.0/demo/SEQ/sound_make.f90 <==
program sound_make
!  ǤΥǥ󥰥եץ.
!  ɬפ˱Ŭ񤭴.
!  ñ̤Ϥ٤ MKS ñ.
  use Thermo_Function
  use Algebra
  use Phys_Const
  use Thermo_Const
  use Thermo_Function

  implicit none

!-- namelist valiables
  integer :: nr, nz  ! ʿľʻ
  integer :: mom_flag
  real :: coril
  real :: dr, dz     ! ʿľʻҴֳ [m]
  character(4) :: bc  ! not use
  character(80) :: fname  ! not use
  character(80) :: sound_name  ! ǥ󥰥ե̾

  real, parameter :: t_s=300.0  ! ɽ̲
  real, parameter :: t_trop=200.0  ! ή̤Ǥβ
  real, parameter :: z_trop=15.0e3  ! ή̹
  real, allocatable :: z(:)  ! 
  real, allocatable :: temp(:)  ! 
  real, allocatable :: theta(:)  ! 
  real, allocatable :: pres(:)  ! 
  real, allocatable :: temp_inv(:)  ! 
  real :: gamma_dd  ! ٸΨ
  real :: p_s  ! ɽ̵,  3 ܻ.

  integer :: i

!-- namelist Υѥ᡼
  namelist /input /nr, nz, dr, dz, bc, fname, sound_name, coril, mom_flag
  read(5,nml=input)

!-- allocate
  allocate(z(nz))
  allocate(temp(nz))
  allocate(theta(nz))
  allocate(pres(nz))
  allocate(temp_inv(nz))

!-- ɽ̵η׻
  p_s=1000.0e2


  z=(/(dz*real(i-1),i=1,nz)/)

  gamma_dd=(t_trop-t_s)/z_trop  ! ̤ޤǤβٸΨ (constant)

  do i=1,nz
     if(z(i)<=z_trop)then
        temp(i)=t_s+gamma_dd*z(i)
     else
        temp(i)=t_trop
     end if
     temp_inv(i)=1.0/temp(i)
  end do

  pres(1)=p_s

  do i=2,nz
     pres(i)=p_s/((gamma_dd*z(i)/t_s+1.0)**(g/(Rd*gamma_dd)))  ! Ψ絤ˤϳشط뼰ѤƷ׻.
  end do

  do i=1,nz
     theta(i)=theta_dry( temp(i), pres(i) )
  end do

!-- ǥ󥰥եؤν񤭽Ф.
  open(unit=10,file=trim(sound_name),status='unknown')
  write(*,*) "output the sounding file."
  write(10,*) "'height',  'temperature',  'pressure',  'potential temperature'"
  write(10,*) "'m',  'K',  'Pa',  'K'"
  do i=1,nz
     write(10,'(1P4E16.8)') z(i), temp(i), pres(i), theta(i)
  end do
  close(unit=10,status='keep')

end program
